#include "NOPackage.h"
#include "NOPage.h"
#include "NOContentStreamNavigator.h"

using namespace NiXPSObjects;

// this examples overlays page 1 of document 1 with page 1 of document 1 of another XPS package
void overlayPage(const UTF8Char *baseXPSdoc, const UTF8Char *overlayXPSdoc, const UTF8Char *pOut)
{
	// start
	NOPackage *basePackage, *overlayPackage;
	NOPage basePage, overlayPage;

	// read base doc, get handler to page in question
	basePackage = NOPackage::readPackageFromFile(baseXPSdoc);
	basePage = basePackage->getDocument(0).getPage(0);

	// read overlay doc, get handler to page in question
	overlayPackage = NOPackage::readPackageFromFile(overlayXPSdoc);
	overlayPage=overlayPackage->getDocument(0).getPage(0);

	// get a content stream navigator in the basePage, navigate to the 'FixedPage'
	NOContentStreamNavigator mergedNav=basePage.getContentStreamNavigator();
	mergedNav.toChild("FixedPage");

	// inject some xml prefix
	mergedNav.insertAsChild("<!-- some prefix xml code -->");

	// get a content stream navigator in the overlayPage, navigate to the 'FixedPage'
	NOContentStreamNavigator overlayNav=overlayPage.getContentStreamNavigator();
	overlayNav.toChild("FixedPage");

	// insert in the overlayNav childs into the merged page
	for (UInt32 lCount=0; lCount<overlayNav.getNumberOfChilds(); lCount++)
	{
		NOContentStreamNavigator lNav=overlayNav;
		lNav.toChild(lCount);
		mergedNav.insertAsChild(lNav);
	}
	
	// inject some xml postfix
	mergedNav.insertAsChild("<!-- some postfix xml code -->");
		
	// So now document 0 has some page 0...

	// copy over the resources
	basePackage->getDocument(0).getPage(0).copyResourcesFrom(overlayPage);
	
	// normalize page content (so the URL's point to correct resources)
	basePage.normalizeContentStream();
		
	basePackage->writePackageToFile(pOut);

	// clean-up
	NOPackage::destroyPackage(overlayPackage);
	NOPackage::destroyPackage(basePackage);
}