// NODocument.h
//
// NODocument: NODocument class
//			
//
// (c) NiXPS NV, October 2006

#ifndef _NODOCUMENT_H_
#define _NODOCUMENT_H_

/*! \file NODocument.h
    \brief Header file for NODocument class
*/

#include "NTypes.h"
#include "NOPartWithResources.h"
#include "NOProgressReporter.h"

// C api
extern "C" {
	DLLIMPORTEXPORT NODocumentHandler NODocument_new(NOHandler* pHandler, NCommon::UInt16 pID);
	DLLIMPORTEXPORT NCommon::UInt32 NODocument_getNumberOfPages(NODocumentHandler* pDocument);
	DLLIMPORTEXPORT NOPageHandler NODocument_getPage(NODocumentHandler* pDocument,  NCommon::UInt32 pNum);
	DLLIMPORTEXPORT NCommon::UInt32 NODocument_getPageNumberOf(NODocumentHandler* pDocument, NOPageHandler pPage);
	DLLIMPORTEXPORT NOPageHandler NODocument_insertPage(NODocumentHandler* pDocument, NOPageHandler pPage,  NCommon::UInt32 pPos/*, void *pReporter*/);
	DLLIMPORTEXPORT NOPageHandler NODocument_createPage(NODocumentHandler* pDocument);
	DLLIMPORTEXPORT NCommon::UInt32 NODocument_searchAndReplaceText(NODocumentHandler* pDocument, NCommon::UTF8Char *pSearch, NCommon::UTF8Char *pReplace, NOFontVectorHandler pMissingFonts/*, void *pReporter*/, NCommon::UInt32 pDryRun);
	DLLIMPORTEXPORT NCommon::UInt32 NODocument_exportToPDF(NODocumentHandler *pDocument, NCommon::UTF8Char *pPDFFileName, NOProgressReporterHandler lProgressReporter);
};

#ifdef NIXPS_CPP_INTERFACE
// C++ api
namespace NiXPSObjects
{

class NOPage;
class NOThumbnail;
class NOFontVector;
class NOProgressReporter;

/*!
 * \class NODocument NODocument.h "NODocument.h"
 * Class representing a document in an XPS package.
 */
class NODocument: public NOPartWithResources
{
	public:
		// constructor
		NODocument();

		// constructor
		NODocument(NODocumentHandler pHandler);

		// destructor
		virtual ~NODocument();

		/// Returns the number of pages
		NCommon::UInt32 getNumberOfPages();

		/// Returns a given page represented by an NOPage object
		/// @param pNum The location of the page to obtain
		NOPage getPage(const UInt32 &pNum);
		
		/// Returns the page number this page has in the document
		/// @param pPage the NOPage object representing the page of which we want to know the page number
		NCommon::UInt32 getPageNumberOf(const NOPage &pPage);
		
		/// Insert a page into a given location
		/// @param pPage the NOPage object representing the page to be inserted
		/// @param pPos the Postion to insert the page at
		NOPage insertPage(const NOPage &pPage, UInt32 pPos/*, NCommon::NProgressReporter *pReporter=0*/);

		/// Creates a new page adding it to the back of the pagelist
		NOPage createPage();

		UInt32 exportToPDF(const UTF8Char *pPDFFileName, NOProgressReporter &pProgressReporter);
		
		/// Search and replace text in a document
		/// @param pSearch String to search for
		/// @param pReplace String to replace search string with
		/// @param pMissingFonts Font vector that will represent the fonts missing to do the replacement if the search and replace fails
		/// @param pDryRun Do a dry run, i.e. only test the search and replace and don't actually perform the operation
		bool searchAndReplaceText(const UTF8Char *pSearch, const UTF8Char *pReplace, NOFontVector &pMissingFonts, /*NCommon::NProgressReporter *pReporter, */bool pDryRun);
};

}
#endif // NIXPS_CPP_INTERFACE

#endif
