// NOFont.h
//
// NOFont: a font
//			
// (c) NiXPS NV, March 2006

#ifndef _NOFONT_H_
#define _NOFONT_H_

/*! \file NOFont.h
    \brief Header file for NOFont class
*/

#include "NTypes.h"
#include "NOPartBased.h"

// C api
extern "C" {
	DLLIMPORTEXPORT NOFontHandler NOFont_new(NOHandler* pHandler, NCommon::UInt16 pID);
	DLLIMPORTEXPORT void NOFont_getFileName(NOFontHandler* pFont, NOStringHandler *pString);
	DLLIMPORTEXPORT void NOFont_getFontFamilyName(NOFontHandler* pFont, NOStringHandler *pString);
	DLLIMPORTEXPORT NCommon::UInt32 NOFont_isRestricted(NOFontHandler* pFont);
	DLLIMPORTEXPORT void NOFont_writeToFile(NOFontHandler* pFont, NCommon::UTF8Char *destinationPath);
	DLLIMPORTEXPORT NCommon::UInt32 NOFont_replaceWithFile(NOFontHandler* pFont, NCommon::UTF8Char *pFontFile);
};

#ifdef NIXPS_CPP_INTERFACE
// C++ api
namespace NiXPSObjects
{

class NOPackage;

/**
 * \class NOFont NOFont.h "NOFont.h"
 * Class representing a font in an XPS package
 */
class NOFont: public NOPartBased
{
	public:
		// constructor: object is always linked to a specific package (and probably also a specific part)
		NOFont(NOFontHandler pHandler);

		// destructor
		virtual ~NOFont();

		/// Returns the filename of the font
		const NCommon::UTF8String getFileName();

		/// Returns the family name of the font
		const NCommon::UTF8String getFontFamilyName();

		/// Returns wheter a font is restricted or not.  A font is restricted when it's relationship in the
		/// XPS package indicates it as such.
		NCommon::UInt32 isRestricted();

		/// Saves font to a file
		/// @param destinationPath An UTF8String with the path
		///			to write the file to.  The path is seperated by forward slashes ('/').
		void writeToFile(const NCommon::UTF8String &destinationPath);

		/// Replaces a font with the given file
		/// @param sourcePath An UTF8String with the path
		///			of the font file to add as a replacement.  The path is seperated by forward slashes ('/').
		bool replaceWithFile(const NCommon::UTF8String &sourcePath);
};

}

#endif // NIXPS_CPP_INTERFACE

#endif
