// Common Types
//
// Some common types
//
// (c) NDR, June 2006

#ifndef _NTYPES_
#define _NTYPES_

/*! \file NTypes.h
    \brief Header file for common NiXPS Library types
*/

#ifndef macosx
	#define win32	1
	#pragma warning( disable : 4251 )
#endif

#include <string>
#include <vector>

// **************************************************************************************
// NDR 30/8/2007
//
// Memory Leak Checker: uncomment this line, and make sure mmgr.cpp is compiled in to use
// #include "mmgr.h"
//
// **************************************************************************************

/*
#ifdef win32
	#ifdef _FLAG
		#if _FLAG
		#define  __declspec(dllexport)
		#else
		#define  __declspec(dllimport)
		#endif
	#else
		#define 
	#endif
#else
	#define 
	#define DLLIMPORTEXPORT
#endif
*/
#ifdef NIXPS_NO_DLL
	#define DLLIMPORTEXPORT
	#define NIXPS_CPP_INTERFACE
#else
	#ifdef win32
		#ifdef NIXPS_BUILD_DLL
			#define DLLIMPORTEXPORT __declspec(dllexport)
		#else
			#define DLLIMPORTEXPORT __declspec(dllimport)
		#endif
	#else
		#define DLLIMPORTEXPORT
	#endif
	#define NIXPS_CPP_INTERFACE
#endif

#ifdef win32
#define strncasecmp _strnicmp
#define strcasecmp _stricmp
#define snprintf _snprintf
#define NPATHSEPARATOR	'\\'
#else
#define NPATHSEPARATOR	'/'
#endif

namespace NCommon
{
	typedef unsigned char 		UInt8;	/**< 8 bits, unsigned */
	typedef unsigned int 		UInt32; /**< 32 bits, unsigned */
	typedef unsigned short		UInt16; /**< 16 bits, unsigned */
	typedef unsigned long long	UInt64; /**< 64 bits, unsigned */

	typedef char				Int8; /**< 8 bits, signed */
	typedef int					Int32; /**< 32 bits, signed */
	typedef short				Int16; /**< 16 bits, signed */
	typedef long long			Int64; /**< 64 bits, signed */

	typedef std::string		UTF8String; /**< UTF-8 encoded string */

	typedef std::string		PlatformCString;
	typedef char			UTF8Char;
	
	typedef std::vector<UInt32>		UTF32CharVector;

	extern bool decodeEntities(const UTF8Char *pStringWithEntities, const UInt32 pLen, UTF8String &pString);
	extern void encodeEntities(const UTF8Char *pString, const UInt32 pLen, UTF8String &pStringWithEntities);

//	extern bool isWhite(const UInt32 &pCurrent);
	#define isWhite(x) ( x==' ' || x=='\t' || x=='\n' || x=='\r' )
};


/*! \namespace NCommon
 * Namespace defining common types for the NiXPS Library
 */

namespace NiXPSAccess {
	class NAPackage;
};

namespace NiXML {
	class XMLDoc;
};

#define NIXPS_CALL_CONST(x,y) \
	x lRet= (x) y (const_cast<NOHandler *>(getNOHandler())); \
	if (mHandler.mError) \
		throw(NOException(mHandler)); \
	return lRet; \

extern "C"
{
	struct NOHandler 
	{
		NiXPSAccess::NAPackage *mPackage;
		NCommon::UInt16 mID;
		NCommon::UInt32 mType;
		NCommon::UInt32 mError;
	};

	struct NOContentStreamNavigatorHandler 
	{
		NiXPSAccess::NAPackage *mPackage;
		NCommon::UInt16 mID;
		NCommon::UInt32 mCursor;
		NCommon::UInt32 mError;
	};
	
	struct NOXHandler 
	{
		NiXML::XMLDoc *mDoc;
		NCommon::UInt16 mType;
		NCommon::UInt32 mCursor;
		NCommon::UInt32 mError;
	};
	
	typedef void (*NOReporterUpdateFunction)(void *pHandle, NCommon::UInt32 pValue);

	struct NOProgressReporterHandler {
		NOReporterUpdateFunction mFunction;
		void *mHandler;
	};
	
	typedef NOHandler NOPackageHandler; 
	typedef NOHandler NOPageHandler;
	typedef NOHandler NODocumentHandler;
	typedef NOHandler NOFontHandler;
	typedef NOHandler NOImageHandler;
	typedef NOHandler NOThumbnailHandler;
	typedef NOHandler NOCorePropertiesHandler;
	typedef NOHandler NOPartWithResourcesHandler;
	typedef NOHandler NOXMLPartBasedHandler;
	
	struct NOVectorHandler 
	{
		NiXPSAccess::NAPackage *mPackage;
		void *mPtr;
	};
	
	typedef NOVectorHandler NOFontVectorHandler;
	typedef NOVectorHandler NOImageVectorHandler;

	struct NOStringHandler 
	{
		void *mPtr;
	};

	typedef NOXHandler NOXBase;
	typedef NCommon::Int32 NOXIntBase;			/**< an integer */

	typedef NCommon::UInt32 NOXBooleanBase;		/**< a boolean */
	typedef double NOXDoubleBase;				/**< a double */
	typedef NOStringHandler NOXStringBase;		/**< a string */
	typedef NOStringHandler NOXUriBase;			/**< a URI */

	
	typedef double NOXZeroOne;					/**< a value */
	typedef double NOXGEZero;					/**< a value >= 0 */
	typedef double NOXDouble;					/**< a double */
	typedef double NOXGEOne;					/**< a value >= 1 */
	typedef NCommon::UInt32 NOXBoolean;			/**< a boolean value */
	typedef NOStringHandler NOXPoint;			/**< a point */
	typedef NOStringHandler NOXPointGE0;		/**<a point greater or equal to 0 */
	typedef NOStringHandler NOXPoints;			/**< a list of point in the XPS context */
	typedef NOStringHandler NOXEvenArrayPos;	/**< an array */
	typedef NOStringHandler NOXArray;			/**< an array */
	typedef NOStringHandler NOXViewBox;			/**< a view box ("x y width height") */
	typedef NOStringHandler NOXContentBox;		/**< a content box ("x y width height") */
	typedef NOStringHandler NOXBleedBox			/**< a bleed box ("x y width height") */;
	typedef NOStringHandler NOXMatrix;			/**< a matrix ("xx xy yx yy offx offy") */
	typedef NOStringHandler NOXColor;			/**< a color */
	typedef NOStringHandler NOXCaretStops;		/**< caret stops */
	typedef NOStringHandler NOXIndices;			/**< Indices */
	typedef NOStringHandler NOXUnicodeString;	/**< a unicode string color */
	typedef NOStringHandler NOXAbbrGeomF;		/**< abbriviated geometry information */
	typedef NOStringHandler NOXAbbrGeom;		/**< abbriviated geometry information */
	typedef NOStringHandler NOXUriImage;		/**< a uri to an image */
	typedef NOStringHandler NOXCtxBmpImage;		/**<  */
	typedef NOStringHandler NOXUriCtxBmp;		/**<  */
	typedef NOStringHandler NOXRscRef;			/**< a reference to a resource */
	typedef NOStringHandler NOXRscRefColor;		/**< a reference to a color resource */
	typedef NOStringHandler NOXRscRefMatrix;	/**< a reference to a matrix resource */
	typedef NOStringHandler NOXRscRefAbbrGeomF;	/**< a reference to an abbriviated geometry information resource */
	typedef NOStringHandler NOXName;			/**< a name */

	// enums: 'ints' for now
	typedef NCommon::Int32 NOXStyleSimulations;	/**<  */
	typedef NCommon::Int32 NOXSweepDirection;	/**<  */
	typedef NCommon::Int32 NOXTileMode;			/**<  */
	typedef NCommon::Int32 NOXViewUnits;		/**<  */
	typedef NCommon::Int32 NOXClrIntMode;		/**<  */
	typedef NCommon::Int32 NOXSpreadMethod;		/**<  */
	typedef NCommon::Int32 NOXMappingMode;		/**<  */
	typedef NCommon::Int32 NOXFillRule;			/**<  */
	typedef NCommon::Int32 NOXDashCap;			/**<  */
	typedef NCommon::Int32 NOXLineCap;			/**<  */
	typedef NCommon::Int32 NOXLineJoin;			/**<  */
	typedef NCommon::Int32 NOXEdgeMode;			/**<  */

};


#endif
