// NOContentStreamNavigator.cpp
//
// NOContentStreamNavigator: navigate the (raw, xml) contentstream
//			
// (c) NiXPS NV, April 2006

/*! \file NOContentStreamNavigator.cpp
    \brief Implementation of the NOContentStreamNavigator class
*/

#include "NOContentStreamNavigator.h"
#include "NOXMLPartBased.h"
#include "NOString.h"

namespace NiXPSObjects
{

using namespace NiXPSAccess;

NOContentStreamNavigator::NOContentStreamNavigator(NOContentStreamNavigatorHandler &pHandler)
{
	mHandler = pHandler;
}

NOContentStreamNavigator::NOContentStreamNavigator(NOXMLPartBased &pPart)
{
	mHandler = NOContentStreamNavigator_new(pPart.getNOHandler());
}

NOContentStreamNavigator::~NOContentStreamNavigator()
{
}

// get the node info
void NOContentStreamNavigator::getNodeInfo(UInt32 &lPos, UInt32 &lLen)
{
	return NOContentStreamNavigator_getNodeInfo(&mHandler,&lPos,&lLen);
}

// get the number of child nodes
NCommon::UInt32 NOContentStreamNavigator::getNumberOfChilds() const
{
	return NOContentStreamNavigator_getNumberOfChilds(&mHandler);
}						

// navigate to child node at index 'pNum'
bool NOContentStreamNavigator::toChild(const UInt32 pNum)
{
	return (NOContentStreamNavigator_toChild(&mHandler,pNum)!=0);
}

bool NOContentStreamNavigator::toChild(const UTF8String &pString, const bool pCaseSensitive, const bool pIgnorePrefix)
{
	NOString lString(pString);
	return (NOContentStreamNavigator_toChildWithName(&mHandler,lString.getHandler(),pCaseSensitive,pIgnorePrefix)!=0);
}

// navigate to sibling
bool NOContentStreamNavigator::toSibling()
{
	return (NOContentStreamNavigator_toSibling(&mHandler)!=0);
}

// get the name of the current node
const NCommon::UTF8String NOContentStreamNavigator::getName() const
{
	NOString lName;
	NOContentStreamNavigator_getName(&mHandler, lName.getHandler());
	return lName.getUTF8String();
}						

// tests for the presence of the given attribute
bool NOContentStreamNavigator::hasAttributeValue(const UTF8String &pKey) const
{
	NOString lString(pKey);
	return (NOContentStreamNavigator_hasAttributeValue(&mHandler,lString.getHandler())!=0);
}

// get the value of an attribute of the current node
const NCommon::UTF8String NOContentStreamNavigator::getAttributeValue(const UTF8String &pKey) const
{
	NOString lAttributeString;
	NOString lKeyString(pKey);
	NOContentStreamNavigator_getAttributeValue(&mHandler,lKeyString.getHandler(),lAttributeString.getHandler());
	return lAttributeString.getUTF8String();
}						

bool NOContentStreamNavigator::setAttributeValue(const UTF8String &pKey, const UTF8String &pValue)
{
	NOString lKeyString(pKey);
	NOString lValueString(pValue);
	return (NOContentStreamNavigator_setAttributeValue(&mHandler,lKeyString.getHandler(),lValueString.getHandler())!=0);
}

bool NOContentStreamNavigator::addAttribute(const UTF8String &pKey, const UTF8String &pValue)
{
	NOString lKeyString(pKey);
	NOString lValueString(pValue);
	return (NOContentStreamNavigator_addAttribute(&mHandler,lKeyString.getHandler(),lValueString.getHandler())!=0);
}

bool NOContentStreamNavigator::toAttributeValue(const UTF8String &pKey)
{
	NOString lKeyString(pKey);
	return (NOContentStreamNavigator_toAttributeValue(&mHandler,lKeyString.getHandler())!=0);
}

// check to see if the current element has character data
bool NOContentStreamNavigator::hasCharacterData() const
{
	return (NOContentStreamNavigator_hasCharacterData(&mHandler)!=0);
}						

// read the character data for the current node
const NCommon::UTF8String NOContentStreamNavigator::getCharacterData() const
{
	NOString retString;
	NOContentStreamNavigator_getCharacterData(&mHandler, retString.getHandler());
	return retString.getUTF8String();
}

bool NOContentStreamNavigator::insertChild(const NCommon::UTF8String &pName, NCommon::UInt32 pPosition, bool pToChild)
{
	NOString lName(pName);
	return (NOContentStreamNavigator_insertChild(&mHandler, lName.getHandler(), pPosition, pToChild)!=0);
}

bool NOContentStreamNavigator::insertAsChild(const UTF8String &pXML)
{
	NOString lXMLString(pXML);
	return (NOContentStreamNavigator_insertAsChild(&mHandler,lXMLString.getHandler())!=0);
}

bool NOContentStreamNavigator::insertAsChild(NOContentStreamNavigator &pNav)
{
	return (NOContentStreamNavigator_insertAsChildWithNavigator(&mHandler,&pNav.mHandler)!=0);
}

}
