// NODocument.h
//
// NODocument: NODocument class
//			
//
// (c) NiXPS NV, October 2006

/*! \file NODocument.cpp
    \brief Implementation of the NODocument class
*/

#include "NTypes.h"
#include "NODocument.h"
#include "NOPage.h"
#include "NOException.h"

namespace NiXPSObjects
{

NODocument::NODocument(): NOPartWithResources() 
{
}

NODocument::NODocument(NODocumentHandler pHandler): NOPartWithResources(pHandler) 
{
};

NODocument::~NODocument() 
{
};

// returns the number of pages
NCommon::UInt32 NODocument::getNumberOfPages()
{
	UInt32 lRet=NODocument_getNumberOfPages(&mHandler);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lRet;
};

// returns the given page (location pNum)
NOPage NODocument::getPage(const UInt32 &pNum)
{
	NOPageHandler lHandler=NODocument_getPage(&mHandler, pNum);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOPage(lHandler);
};
		
// returns the page number this page has in the doc
NCommon::UInt32 NODocument::getPageNumberOf(const NOPage &pPage)
{
	UInt32 lRet=NODocument_getPageNumberOf(&mHandler, *const_cast<NOPageHandler *>(pPage.getNOHandler()));

	if (mHandler.mError)
		throw(NOException(mHandler));
		
	return lRet;
};
		
// insert a page into a given location
NOPage NODocument::insertPage(const NOPage &pPage, UInt32 pPos/*, NCommon::NProgressReporter *pReporter=0*/)
{
	NOPageHandler lHandler=NODocument_insertPage(&mHandler, *const_cast<NOPageHandler *>(pPage.getNOHandler()), pPos/*, pReporter*/);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOPage(lHandler);
};

// creates a new page, adds this to the back of the pagelist
NOPage NODocument::createPage()
{
	NOPageHandler lHandler = NODocument_createPage(&mHandler);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOPage(lHandler);
}

// search and replace text in a document
bool NODocument::searchAndReplaceText(const UTF8Char *pSearch, const UTF8Char *pReplace, NOFontVector &pMissingFonts, /*NCommon::NProgressReporter *pReporter, */const bool pDryRun)
{
	UInt32 lRet=NODocument_searchAndReplaceText(getNOHandler(), const_cast<UTF8Char *>(pSearch), const_cast<UTF8Char *>(pReplace), pMissingFonts.getHandler(), /*void *pReporter,*/ pDryRun);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return (lRet!=0);
}

UInt32 NODocument::exportToPDF(const UTF8Char *pPDFFileName, NOProgressReporter &pProgressReporter)
{
	UInt32 lRet = NODocument_exportToPDF(getNOHandler(),const_cast<UTF8Char*>(pPDFFileName),pProgressReporter.getHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet;
}

};
