// NOFont.h
//
// NOFont: a font
//			
//
// (c) NiXPS NV, June 2007

/*! \file NOFont.cpp
    \brief Implementation of the NOFont class
*/

#include "NOFont.h"
#include "NOString.h"
#include "NOException.h"
#include "NOString.h"

// constructor: object is always linked to a specific package (and probably also a specific part)
NiXPSObjects::NOFont::NOFont(NOFontHandler pHandler): NOPartBased(pHandler)
{
}

// destructor
NiXPSObjects::NOFont::~NOFont()
{
}

// returns the filename of the font
const NCommon::UTF8String NiXPSObjects::NOFont::getFileName()
{
	NOString lName;
	NOFont_getFileName(&mHandler,lName.getHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lName.getUTF8String();
}

// returns the family name of the font
const NCommon::UTF8String NiXPSObjects::NOFont::getFontFamilyName()
{
	NOString lName;
	NOFont_getFontFamilyName(&mHandler,lName.getHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lName.getUTF8String();
}

// is a font restricted
NCommon::UInt32 NiXPSObjects::NOFont::isRestricted()
{
	UInt32 lRet=NOFont_isRestricted(&mHandler);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lRet;
}

// saves font to a file	
void NiXPSObjects::NOFont::writeToFile(const UTF8String &destinationPath)
{
	NOFont_writeToFile(&mHandler,const_cast<UTF8Char *>(destinationPath.c_str()));

	if (mHandler.mError)
		throw(NOException(mHandler));
}

// replaces a font with the given file
bool NiXPSObjects::NOFont::replaceWithFile(const UTF8String &destinationPath)
{
	UInt32 lRet=NOFont_replaceWithFile(&mHandler,const_cast<UTF8Char *>(destinationPath.c_str()));

	if (mHandler.mError)
		throw(NOException(mHandler));

	return (lRet!=0);
}
