// NOImageDLL.cpp
//
// NOImageDLL
//			
//
// (c) NiXPS NV, June 2007

/*! \file NOImage.cpp
    \brief Implementation of the NOImage class
*/

#define NIXPS_CPP_INTERFACE

#include "NOImage.h"
#include "NOException.h"
#include "NOString.h"

using namespace NiXPSObjects;

NOImage::NOImage(NOImageHandler pHandler): NOPartBased(pHandler)
{
}

// destructor
NOImage::~NOImage()
{
}

// returns the filename of the image
const NCommon::UTF8String NOImage::getFileName()
{
	NOString mFilename;
	NOImage_getFileName(&mHandler,mFilename.getHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return mFilename.getUTF8String();
}

// gets the image type
NCommon::Image::Format NOImage::getFormat()
{
	Image::Format lRet=(Image::Format)NOImage_getFormat(&mHandler);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lRet;
}

void NOImage::writeImageToFile(const NCommon::UTF8String &destinationPath)
{
	NOImage_writeImageToFile(&mHandler, const_cast<UTF8Char *>(destinationPath.c_str()));

	if (mHandler.mError)
		throw(NOException(mHandler));
}

// Fill pBuffer with the image data, and 
bool NOImage::getImageData(NCommon::UInt8 *pBuffer, NCommon::UInt32 pSize)
{
	UInt32 lRet=NOImage_getImageData(getNOHandler(), pBuffer, pSize);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return (lRet!=0);
}

// Return the size of the image in bytes (UInt8's)
NCommon::UInt32 NOImage::getImageSize() const
{
	NIXPS_CALL_CONST(NCommon::UInt32,NOImage_getImageSize);
}

/// Returns the width of the image in pixels
NCommon::UInt32 NOImage::getWidthInPixels() const
{
	NIXPS_CALL_CONST(NCommon::UInt32,NOImage_getWidthInPixels);
}

/// Returns the height of the image in pixels
NCommon::UInt32 NOImage::getHeightInPixels() const
{
	NIXPS_CALL_CONST(NCommon::UInt32,NOImage_getHeightInPixels);
}

/// Returns resolution of the image in the X direction
double NOImage::getXResolution() const
{
	NIXPS_CALL_CONST(double,NOImage_getXResolution);
}

/// Returns resolution of the image in the Y direction
double NOImage::getYResolution() const
{
	NIXPS_CALL_CONST(double,NOImage_getYResolution);
}

/// Returns the colortype of the image
Image::ColorType NOImage::getColorType() const
{
	NIXPS_CALL_CONST(Image::ColorType,NOImage_getColorType);
}

/// Returns the bitdepth of the image
Image::BitDepth NOImage::getBitDepth() const
{
	NIXPS_CALL_CONST(Image::BitDepth,NOImage_getBitDepth);
}
