// NOPackage.h
//
// Object that represents a complete package
//			
// (c) NiXPS NV, October 2006

/*! \file NOPackage.cpp
    \brief Implementation of the NOPackage class
*/

#include "NTypes.h"
#include "NOPartBased.h"
#include "NOPackage.h"
#include "NOCoreProperties.h"
#include "NODocument.h"
#include "NOException.h"
#include "NOString.h"

namespace NiXPSObjects
{

using namespace NiXPSAccess;

NOPackage::NOPackage(NOPackageHandler pHandler): NOPartWithResources(pHandler)
{
}

NOPackage::~NOPackage()
{
}

NOPackage * NOPackage::createPackage(bool pCreateEmptyDoc, const UTF8Char *pName)
{
	NOPackageHandler lHandler=NOPackage_create(pCreateEmptyDoc, const_cast<UTF8Char *>(pName));

	if (lHandler.mError)
		throw(NOException(lHandler));

	return new NOPackage(lHandler);
}

void NOPackage::destroyPackage(NOPackage *pXPSPackage)
{	
	NOPackage_destroyPackage(pXPSPackage->getNOHandler());
	delete pXPSPackage;
}

NOPackage * NOPackage::readPackageFromFile(const UTF8String &pFilename)
{
	NOPackageHandler lHandler=NOPackage_readPackageFromFile(const_cast<UTF8Char*>(pFilename.c_str()));
	
	if (lHandler.mError)
		throw(NOException(lHandler));

	NOPackage *lXPS=new NOPackage(lHandler);

	return lXPS;
}

void NOPackage::writePackageToFile(const UTF8String &pFilename) // const
{
	NOPackage_writePackageToFile(getNOHandler(),const_cast<UTF8Char*>(pFilename.c_str()));
	if (mHandler.mError)
		throw(NOException(mHandler));
}

void NOPackage::writePackageToFile() 
{
	NOPackage_save(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
}

// returns the filename
bool NOPackage::hasOutputFilename() const
{
	UInt32 lRet=NOPackage_hasFilename(const_cast<NOPackageHandler *>(&mHandler));
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet!=0;
}

// returns the filename
const UTF8String NOPackage::getOutputFilename() const
{
	NOString lName;
	NOPackage_getFilename(const_cast<NOPackageHandler *>(&mHandler),lName.getHandler());
	
	if (mHandler.mError)
		throw(NOException(mHandler));

	return lName.getUTF8String();
}

// set the filename
void NOPackage::setOutputFilename(const UTF8Char *pFilename)
{
	NOPackage_setFilename(&mHandler,const_cast<UTF8Char *>(pFilename));

	if (mHandler.mError)
		throw(NOException(mHandler));
}

// returns if the package is 'dirty' - meaning that new stuff sits in memory 
bool NOPackage::getDirty()
{
	UInt32 lRet=NOPackage_getDirty(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return (lRet!=0);
}

// returns true if we have a NOCoreProperties object
bool NOPackage::hasCoreProperties()
{
	UInt32 lRet=NOPackage_hasCoreProperties(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return (lRet!=0);
}

// returns a NOCoreProperties object
NOCoreProperties NOPackage::getCoreProperties()
{
	NOCorePropertiesHandler lHandler=NOPackage_getCoreProperties(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return NOCoreProperties(lHandler);
}

NCommon::UInt32 NOPackage::getNumberOfDocuments()
{
	UInt32 lRet=NOPackage_getNumberOfDocuments(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet;
}

// returns a NOCoreProperties object
NODocument NOPackage::getDocument(const UInt32 &pNum)
{	
	NODocumentHandler lHandler=NOPackage_getDocument(getNOHandler(), pNum);
	if (mHandler.mError)
		throw(NOException(mHandler));
	return NODocument(lHandler);
}

// adds a document
void NOPackage::addDocument(const NODocument &pDoc, NOProgressReporter &pReporter)
{	
	NOPackage_addDocument(getNOHandler(), *const_cast<NODocumentHandler *>(pDoc.getNOHandler()), pReporter.getHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
}

// returns the document number this doc has in the xps package
NCommon::UInt32 NOPackage::getDocumentNumberOf(const NODocument &pDoc)
{
	UInt32 lRet=NOPackage_getDocumentNumberOf(getNOHandler(), *const_cast<NODocumentHandler *>(pDoc.getNOHandler()));
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet;
}

bool NOPackage::hasThumbnail()
{
	UInt32 lRet=NOPackage_hasThumbnail(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return (lRet!=0);
}

// returns the NOThumbnail object
NOThumbnail NOPackage::getThumbnail()
{
	NOThumbnailHandler lHandler=NOPackage_getThumbnail(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return NOThumbnail(lHandler);
}

NCommon::UInt32 NOPackage::getNumberOfPages()
{
	UInt32 lRet=NOPackage_getNumberOfPages(getNOHandler());
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet;
}

}
