// NOPage.cpp
//
// NOPage: NOPage class
//			
// (c) NiXPS NV, November 2006

/*! \file NOPage.cpp
    \brief Implementation of the NOPage class
*/

#include "NOXPrefix.h"
#include "NODocument.h"
#include "NOPage.h"
#include "NOException.h"

namespace NiXPSObjects
{

NOPage::NOPage(): NOPartWithResources() 
{
}

NOPage::NOPage(const NOPageHandler pHandler): NOPartWithResources(pHandler) 
{
};

// destructor
NOPage::~NOPage()
{
}

// returns the count of the number of fonts and a vector with all the fonts
NCommon::UInt32 NOPage::getFonts(NOFontVector &pFonts)
{
	UInt32 lRet=NOPage_getFonts(getNOHandler(), pFonts.getHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lRet;
}

NOFont NOPage::getFont(const UTF8Char *pURI)
{
	NOFontHandler lHandler = NOPage_getFont(getNOHandler(), const_cast<UTF8Char*>(pURI));

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOFont(lHandler);
}

NOImage NOPage::getImage(const UTF8String &pURI)
{
	NOImageHandler lHandler = NOPage_getImage(getNOHandler(), const_cast<UTF8Char*>(pURI.c_str()));

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOImage(lHandler);
}

// returns the count of the number of images and a vector with all the images
NCommon::UInt32 NOPage::getImages(NOImageVector &pImages)
{
	UInt32 lRet=NOPage_getImages(getNOHandler(), pImages.getHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lRet;
}
		
// returns the document this page belongs to
NODocument NOPage::getDocument() const
{
	NODocumentHandler lHandler = NOPage_getDocument(const_cast<NOPageHandler *>(getNOHandler()));

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NODocument(lHandler);
}

// add a font to this page, returns a handler to the new font
NOFont NOPage::addFont(const NOFont &pFont)
{
	NOFontHandler lHandler=NOPage_addFont(const_cast<NOFontHandler *>(getNOHandler()), *pFont.getNOHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOFont(lHandler);
}

// add a font to this page, returns a handler to the new font
NOFont NOPage::addFont(const UTF8Char *pFontFile)
{
	NOFontHandler lHandler=NOPage_addFontFile(const_cast<NOFontHandler *>(getNOHandler()), const_cast<UTF8Char *>(pFontFile));

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOFont(lHandler);
}

// add an image font to this page, returns a handler to the new image
NOImage NOPage::addImage(const NOImage &pImage)
{
	NOImageHandler lHandler=NOPage_addImage(const_cast<NOImageHandler *>(getNOHandler()), *pImage.getNOHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));

	return NOImage(lHandler);
}

// copy over the resources from a given other page
void NOPage::copyResourcesFrom(const NOPage &pPage)
{
	NOPage_copyResourcesFrom(getNOHandler(), const_cast<NOPageHandler *>(pPage.getNOHandler()));

	if (mHandler.mError)
		throw(NOException(mHandler));
}

// normalize the content stream
void NOPage::normalizeContentStream()
{
	NOPage_normalizeContentStream(getNOHandler());

	if (mHandler.mError)
		throw(NOException(mHandler));
}
		
// get the page size
void NOPage::getPageSize(double &pWidth, double &pHeight)
{
	NOPage_getPageSize(getNOHandler(), pWidth, pHeight);

	if (mHandler.mError)
		throw(NOException(mHandler));
}

// get the page number
NCommon::UInt32 NOPage::getPageNumber() const
{
	UInt32 lRet=NOPage_getPageNumber(const_cast<NOPageHandler *>(getNOHandler()));

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lRet;
}

// returns a handler to the content (entry point into the XSD world)
NOXFixedPage NOPage::getFixedPage()
{
	NOXFixedPage lHandler=NOPage_getFixedPage(&mHandler);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lHandler;
}

// creates content (entry point into the XSD world)
NOXFixedPage NOPage::createFixedPage()
{
	NOXFixedPage lHandler=NOPage_createFixedPage(&mHandler);

	if (mHandler.mError)
		throw(NOException(mHandler));

	return lHandler;
}

UInt32 NOPage::renderToImage(unsigned char *pImageBuffer, UInt32 pWidth, UInt32 pHeight, bool pAntiAliasing)
{
	UInt32 lRet = NOPage_renderToImage(getNOHandler(),pImageBuffer,pWidth,pHeight,pAntiAliasing);
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet;
}

UInt32 NOPage::renderToTiff(const UTF8Char *pFile, UInt32 pWidth, UInt32 pHeight, UInt32 pResolutionInPixelsPerInch, UInt32 pAntiAliasing)
{
	UInt32 lRet =  NOPage_renderToTiff(getNOHandler(), const_cast<UTF8Char *>(pFile), pWidth, pHeight, pResolutionInPixelsPerInch, pAntiAliasing);
	if (mHandler.mError)
		throw(NOException(mHandler));
	return lRet;
}

}
